==> elevarm_ui-0.7.2.tar.gz: lib/src/components/dialogs/elevarm_image_preview_dialog.dart <==
import 'dart:ui';

import 'package:elevarm_icons/elevarm_icons.dart';
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

class ElevarmImagePreviewDialog {
  /// Dialog's title.
  final String title;

  /// Image URl.
  final String imageUrl;

  /// Callback on close button.
  final VoidCallback onPressedClose;

  /// Callback on fullscreen button.
  final VoidCallback onPressedFullscreen;

  const ElevarmImagePreviewDialog({
    required this.title,
    required this.imageUrl,
    required this.onPressedClose,
    required this.onPressedFullscreen,
  });

  Future<void> show(BuildContext context) {
    return showDialog(
      context: context,
      barrierColor: const Color.fromRGBO(16, 24, 40, 0.35),
      builder: (context) {
        return BackdropFilter(
          filter: ImageFilter.blur(sigmaX: 4.0, sigmaY: 4.0),
          child: Dialog(
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(12),
            ),
            child: Container(
              padding: const EdgeInsets.symmetric(
                horizontal: 16,
                vertical: 20,
              ),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Row(
                    children: [
                      Expanded(
                        child: Text(
                          title,
                          style: ElevarmFontFamilies.poppins(
                            fontWeight: ElevarmFontWeights.semibold,
                            fontSize: ElevarmFontSizes.lg,
                          ),
                        ),
                      ),
                      const SizedBox(width: 16.0),
                      ElevarmLinkNeutralButton.iconOnly(
                        iconAssetName: ElevarmIconsOutline.xClose,
                        onPressed: onPressedClose,
                      ),
                    ],
                  ),
                  const SizedBox(height: 20.0),
                  Image.network(
                    imageUrl,
                    height: 200.0,
                  ),
                  const SizedBox(height: 16.0),
                  ElevarmLinkNeutralButton.icon(
                    text: 'Fullscreen',
                    leadingIconAssetName: ElevarmIconsOutline.maximize01,
                    trailingIconAssetName: null,
                    onPressed: onPressedFullscreen,
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}

==> elevarm_ui-0.10.0.tar.gz: lib/src/components/dialogs/elevarm_image_preview_dialog.dart <==
import 'dart:ui';

import 'package:elevarm_icons/elevarm_icons.dart';
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:flutter/material.dart';

class ElevarmImagePreviewDialog {
  /// Dialog's title.
  final String title;

  /// Image URl.
  final String imageUrl;

  /// Callback on close button.
  final VoidCallback onPressedClose;

  /// Callback on fullscreen button.
  final VoidCallback onPressedFullscreen;

  const ElevarmImagePreviewDialog({
    required this.title,
    required this.imageUrl,
    required this.onPressedClose,
    required this.onPressedFullscreen,
  });

  Future<void> show(BuildContext context) {
    return showDialog(
      context: context,
      barrierColor: const Color.fromRGBO(16, 24, 40, 0.35),
      builder: (context) {
        return BackdropFilter(
          filter: ImageFilter.blur(sigmaX: 4.0, sigmaY: 4.0),
          child: Dialog(
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(12),
            ),
            child: Container(
              padding: const EdgeInsets.symmetric(
                horizontal: 16,
                vertical: 20,
              ),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Row(
                    children: [
                      Expanded(
                        child: Text(
                          title,
                          style: ElevarmFontFamilies.poppins(
                            fontWeight: ElevarmFontWeights.semibold,
                            fontSize: ElevarmFontSizes.lg,
                          ),
                        ),
                      ),
                      const SizedBox(width: 16.0),
                      ElevarmLinkNeutralButton.iconOnly(
                        iconAssetName: ElevarmIconsOutline.x_close,
                        onPressed: onPressedClose,
                      ),
                    ],
                  ),
                  const SizedBox(height: 20.0),
                  Image.network(
                    imageUrl,
                    height: 200.0,
                  ),
                  const SizedBox(height: 16.0),
                  ElevarmLinkNeutralButton.icon(
                    text: 'Fullscreen',
                    leadingIconAssetName: ElevarmIconsOutline.maximize_01,
                    trailingIconAssetName: null,
                    onPressed: onPressedFullscreen,
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
